==> views_pipeline_core-0.2.0-py3-none-any.whl: views_pipeline_core/templates/model/template_main.py <==
from views_pipeline_core.templates.utils import save_script
from pathlib import Path
import logging

logger = logging.getLogger(__name__)


def generate(script_path: Path) -> bool:
    """
    Generates a Python script that sets up and executes model runs with Weights & Biases (WandB) integration.

    This function creates a script that imports necessary modules, sets up project paths, and defines the
    main execution logic for running either a single model run or a sweep of model configurations. The
    generated script includes command-line argument parsing, validation, and runtime logging.

    Parameters:
        script_path (Path):
            The path where the generated Python script will be saved. This should be a valid writable
            path that exists within the project structure.

    Returns:
        bool:
            True if the script was successfully written to the specified directory, False otherwise.

    The generated script includes the following features:
    - Imports required libraries and sets up the path to include the `common_utils` module.
    - Initializes project paths using the `setup_project_paths` function.
    - Parses command-line arguments with `parse_args`.
    - Validates arguments to ensure correctness with `validate_arguments`.
    - Logs into Weights & Biases using `wandb.login()`.
    - Executes a model run based on the provided command-line flags, either initiating a sweep or a single run.
    - Calculates and prints the runtime of the execution in minutes.

    Note:
        - Ensure that the `common_utils` module and all other imported modules are accessible from the
          specified script directory.
        - The generated script is designed to be executed as a standalone Python script.
    """
    code = f"""import wandb
import warnings
from pathlib import Path
from views_pipeline_core.cli.utils import parse_args, validate_arguments
from views_pipeline_core.logging.utils import setup_logging
from views_pipeline_core.managers.model import ModelPathManager

# Import your model manager class here
# E.g. from views_stepshifter.manager.stepshifter_manager import StepshifterManager

warnings.filterwarnings("ignore")

try:
    model_path = ModelPathManager(Path(__file__))
except Exception as e:
    raise RuntimeError(f"An unexpected error occurred: {{e}}.")

logger = setup_logging(logging_path=model_path.logging)


if __name__ == "__main__":
    wandb.login()
    args = parse_args()
    validate_arguments(args)
    if args.sweep:
        # YourModelManager(model_path=model_path).execute_sweep_run(args)
    else:
        # YourModelManager(model_path=model_path).execute_single_run(args)
"""
    return save_script(script_path, code)

==> views_pipeline_core-1.1.0-py3-none-any.whl: views_pipeline_core/templates/model/template_main.py <==
from views_pipeline_core.templates.utils import save_python_script
from pathlib import Path
import logging

logger = logging.getLogger(__name__)


def generate(script_path: Path) -> bool:
    """
    Generates a Python script that sets up and executes model runs with Weights & Biases (WandB) integration.

    This function creates a script that imports necessary modules, sets up project paths, and defines the
    main execution logic for running either a single model run or a sweep of model configurations. The
    generated script includes command-line argument parsing, validation, and runtime logging.

    Parameters:
        script_path (Path):
            The path where the generated Python script will be saved. This should be a valid writable
            path that exists within the project structure.

    Returns:
        bool:
            True if the script was successfully written to the specified directory, False otherwise.

    The generated script includes the following features:
    - Imports required libraries and sets up the path to include the `common_utils` module.
    - Initializes project paths using the `setup_project_paths` function.
    - Parses command-line arguments with `parse_args`.
    - Validates arguments to ensure correctness with `validate_arguments`.
    - Logs into Weights & Biases using `wandb.login()`.
    - Executes a model run based on the provided command-line flags, either initiating a sweep or a single run.
    - Calculates and prints the runtime of the execution in minutes.

    Note:
        - Ensure that the `common_utils` module and all other imported modules are accessible from the
          specified script directory.
        - The generated script is designed to be executed as a standalone Python script.
    """
    code = """import wandb
import warnings
from pathlib import Path
from views_pipeline_core.cli.utils import parse_args, validate_arguments
from views_pipeline_core.managers.log import LoggingManager
from views_pipeline_core.managers.model import ModelPathManager

# Import your model manager class here
# E.g. from views_stepshifter.manager.stepshifter_manager import StepshifterManager

warnings.filterwarnings("ignore")

try:
    model_path = ModelPathManager(Path(__file__))
    logger = LoggingManager(model_path).get_logger()
except FileNotFoundError as fnf_error:
    raise RuntimeError(
        f"File not found: {fnf_error}. Check the file path and try again."
    )
except PermissionError as perm_error:
    raise RuntimeError(
        f"Permission denied: {perm_error}. Check your permissions and try again."
    )
except Exception as e:
    raise RuntimeError(f"Unexpected error: {e}. Check the logs for details.")

if __name__ == "__main__":
    wandb.login()
    args = parse_args()
    validate_arguments(args)
    if args.sweep:
        # YourModelManager(model_path=model_path).execute_sweep_run(args)
    else:
        # YourModelManager(model_path=model_path).execute_single_run(args)
"""
    return save_python_script(script_path, code)
